% Chapter_1_characteristics.m
%
% An Introduction to Partial Differential Equations with MATLAB
% Third Edition
% Chapter 1: Introduction
% Section 1.6: The Method of Characteristics I
%
%  2024 by Matthew P. Coleman and Vladislav Bukshtynov
% VladislavBukshtynov@yahoo.com
%

close all; clear; clc;
set(groot, 'DefaultFigureColormap', jet);

% Example 1
% visualizing u(x,t) = sin(x-2*t/3) using mesh plot
figure(1);
x = -10:0.2:10;              % discretizing x-interval
t = 0:0.2:5;                 % discretizing t-interval
[X,T] = meshgrid(x,t);       % creating (x,t)-grid
u = sin(X-(2/3)*T);          % solution function on (x,t)-grid
mesh(X,T,u);                 % mesh plot using mesh
xlabel('x'); ylabel('t'); zlabel('u(x,t)');
set(gca,'FontSize',14,'yLim',[0 5],'zLim',[-2 2]); box off; view([25 37]);

% Example 2
% visualizing u = exp(-xi)*cos(3*eta) using mesh plot
figure(2);
xi = 0:0.1:3;                % discretizing xi-interval
eta = -5:0.2:5;              % discretizing eta-interval
[Xi,Eta] = meshgrid(xi,eta); % creating (xi,eta)-grid
u = exp(-Xi).*cos(3*Eta);    % solution function on (xi,eta)-grid
mesh(Xi,Eta,u);              % mesh plot using mesh
xlabel('\xi'); ylabel('\eta'); zlabel('u(\xi,\eta)');
set(gca,'FontSize',14,'xLim',[0 3],'yLim',[-5 5],'zLim',[-2 2]); box off; view([-124 26]);

% visualizing u = exp(-x)*cos(3*(4x+y)) using mesh plot
figure(3);
x = 0:0.1:3;                 % discretizing x-interval
y = -5:0.2:5;                % discretizing y-interval
[X,Y] = meshgrid(x,y);       % creating (x,y)-grid
u = exp(-X).*cos(3*(4*X+Y)); % solution function on (x,y)-grid
mesh(X,Y,u);                 % mesh plot using mesh
xlabel('x'); ylabel('y'); zlabel('u(x,y)');
set(gca,'FontSize',14,'xLim',[0 3],'yLim',[-5 5],'zLim',[-2 2]); box off; view([-124 26]);
