% Chapter_1_graph_intersection.m
%
% An Introduction to Partial Differential Equations with MATLAB
% Third Edition
% Chapter 1: Introduction
% Section 1.9: Eigenvalue Problems
% Plotting Figure 1.2 for Example 3
%
%  2024 by Matthew P. Coleman and Vladislav Bukshtynov
% VladislavBukshtynov@yahoo.com
%

close all; clear; clc;

% Defining plotting domain, spacial discretization (mesh), and functions
k = 0:0.01:12;
y1 = -k;
y2 = tan(k);
y2(find(abs(y2)>20)) = NaN; % removing "jumps between infinities"

% Visualization
figure(1); hold on;
plot(k,y1,'-b','LineWidth',2.5); % plotting y1 = -k
plot(k,y2,'-r','LineWidth',2.5); % plotting y2 = tan(k)
for i = 0:3                      % plotting asymptotes
  plot([pi*(0.5+i) pi*(0.5+i)],[-10 10],'--k','LineWidth',1.0);
end

% Setting legend and other graph settings
leg = legend('$y = -k$','$y = \tan k$');
set(leg,'Interpreter','latex','Location','NorthEast');
legend boxoff; axis([0 11 -10 10]); box off;
set(gca,'FontSize',14,'xTick',[pi/2 3*pi/2 5*pi/2 7*pi/2]);
set(gca,'xTickLabel',{'\pi/2' '3\pi/2' '5\pi/2' '7\pi/2'});
xlabel('$k$','Interpreter','latex');
