% Chapter_10_bessel_spherical.m
%
% An Introduction to Partial Differential Equations with MATLAB
% Third Edition
% Chapter 10: PDEs in Higher Dimensions
% Section 10.7: Problems in Spherical Coordinates
%
%  2024 by Matthew P. Coleman and Vladislav Bukshtynov
% VladislavBukshtynov@yahoo.com
%

close all; clear; clc;
set(groot, 'DefaultFigureColormap', jet);

% Plotting Figure 10.17 for Section 10.7
% spherical Bessel functions
x = 0:0.01:10;                              % discretizing x-interval
figure(1); hold on;
plot(x,sqrt(pi./(2*x)).*besselj(0+0.5,x),'r-','LineWidth',2);  % n = 0
plot(x,sqrt(pi./(2*x)).*besselj(1+0.5,x),'r--','LineWidth',2); % n = 1
plot(x,sqrt(pi./(2*x)).*besselj(2+0.5,x),'b-','LineWidth',2);  % n = 2
plot(x,sqrt(pi./(2*x)).*besselj(3+0.5,x),'b--','LineWidth',2); % n = 3
xlabel('x'); ylabel('j_n(x)');
title('spherical Bessel functions: j_n(x)');
legend('n = 0','n = 1','n = 2','n = 3','Location','NorthEast');
set(gca,'FontSize',14); box off; legend boxoff;
