% Chapter_10_vibration_modes_disk.m
%
% An Introduction to Partial Differential Equations with MATLAB
% Third Edition
% Chapter 10: PDEs in Higher Dimensions
% Section 10.6: TheWave and Heat Equations in Polar Coordinates
%
%  2024 by Matthew P. Coleman and Vladislav Bukshtynov
% VladislavBukshtynov@yahoo.com
%

close all; clear; clc;
set(groot, 'DefaultFigureColormap', jet);

% Plotting Figure 10.13 for Section 10.6
[th,r] = meshgrid((0:10:360)*pi/180,0:0.1:1); % meshgrid
[x,y] = pol2cart(th,r);                       % projection polar to Cartesian coordinates
Xnm = [2.40483 5.52008  8.65373;              % zeros of Bessel function J_n
       3.83171 7.01559 10.17347;
       5.13562 8.41724 11.61984];
for n = [0 1 2]
  for m = [1 2 3]
    r = sqrt(x.^2 + y.^2);
    v = besselj(n,Xnm(n+1,m).*r).*cos(n*th);
    figure; surf(x,y,v);
    xlabel('x'); ylabel('y');
    set(gca,'FontSize',14); view([-32 12]); box off;
  end
end
