% Chapter_3_symbolic_math_BVPs.m
%
% An Introduction to Partial Differential Equations with MATLAB
% Third Edition
% Chapter 3: Using MATLAB for Solving DEs and Visualizing Solutions
% Section 3.2: Symbolic Math Toolbox for Solving ODEs
% Solving BVP (eigenvalue problem) in Example 1 of Section 1.7
%
%  2024 by Matthew P. Coleman and Vladislav Bukshtynov
% VladislavBukshtynov@yahoo.com
%

close all; clear; clc;

% problem: y'' + lambda y = 0, y(0) = y(1) = 0
% normalization condition: y'(0) = 1

% attempt #1: solving problem with unknown eigenvalue lambda
syms y(x) lambda;                       % creating symbolic functions
D = diff(y,x);                          % defining derivative y'(x)
ode = diff(D)+lambda*y == 0;            % defining ODE (2-order)
cond = [y(0) == 0 y(1) == 0 D(0) == 1]; % setting all conditions
Ysol(x) = dsolve(ode,cond);             % solving BVP using dsolve
Ysol = simplify(Ysol)                   % simplifying & displaying solution

% attempt #2: solving problem with known eigenvalue lambda (for n = 1)
clear lambda;                           % deleting symbolic variable lambda
n = 1; lambda = (n*pi)^2;               % defining eigenvalue #1
ode = diff(D)+lambda*y == 0;            % defining ODE (now with constant lambda)
Ysol(x) = dsolve(ode,cond);             % solving BVP using dsolve
Ysol = simplify(Ysol)                   % simplifying & displaying solution

% attempt #3: after removing normalization condition
cond = [y(0) == 0 y(1) == 0];            % setting BCs
Ysol(x) = dsolve(ode,cond);              % solving BVP using dsolve
Ysol = simplify(Ysol)                    % simplifying & displaying solution

% attempt #4: checking general ability to solve BVPs
ode = diff(D) + y == 0;                  % re-defining ODE
cond = [y(0) == 1 y(1) == 1];            % setting new BCs
Ysol(x) = dsolve(ode,cond)               % solving BVP using dsolve
Ysol = simplify(Ysol)                    % simplifying & displaying solution
