% Chapter_4_fourier_series.m
%
% An Introduction to Partial Differential Equations with MATLAB
% Third Edition
% Chapter 4: Fourier Series
% Section 4.4: The Fourier Series, Continued
%
%  2024 by Matthew P. Coleman and Vladislav Bukshtynov
% VladislavBukshtynov@yahoo.com
%

close all; clear; clc;

% Plotting Figure 4.7 for Example 3
x1 = 1:0.01:2;  % spacial x-discretization for interval [1, 2]
x2 = 2:0.01:3;  % spacial x-discretization for interval [2, 3]
y1 = x1;        % defining function y(x)
y2 = 1./(x2-2); 
figure(1); hold on;
plot(x1,y1,'-r','LineWidth',2.5);     % plotting y(x)
plot(x2,y2,'-r','LineWidth',2.5);
plot([x1(1) x1(end) x2(end)],[y1(1) y1(end) y2(end)],'r.','MarkerSize',30);
plot([2 2],[0 6],'--k','LineWidth',1) % vertical asymptote
box off;                              % various settings for graph
xlabel('$x$','Interpreter','latex'); ylabel('$y$','Interpreter','latex');
axis([1 3 0 6]); set(gca,'FontSize',14);

% Plotting Figures 4.9(a) and 4.9(b) for Example 5
x = -2:0.01:2;              % spacial x-discretization for interval [-2, 2]
y = sign(x).*abs(x.^(1/3)); % defining new function y(x)
y1 = (1/3)*abs(x.^(-2/3));  % defining derivative y'(x)
% Use of functions ABS and SIGN (-1 if x<0 & 1 if x>0) allows Matlab
% to select only real (not complex) cube roots.
figure(2); hold on;
plot(x,y,'-r','LineWidth',2.5);           % plotting y(x)
plot([-pi pi],[0 0],'--k','LineWidth',1); % plotting y = 0
plot(0,0,'r.','MarkerSize',30);
box off;                                  % various settings for graph
xlabel('$x$','Interpreter','latex'); ylabel('$y$','Interpreter','latex');
axis([-2 2 -2 2]); set(gca,'FontSize',14)
figure(3); hold on;
plot(x,y1,'-r','LineWidth',2.5);          % plotting y'(x)
plot([-2 2],[0 0],'--k','LineWidth',1);   % plotting y = 0
plot([0 0],[-1 3],'--k','LineWidth',1);   % vertical asymptote x = 0
box off;                                  % various settings for graph
xlabel('$x$','Interpreter','latex'); ylabel('$y$','Interpreter','latex');
axis([-2 2 -1 3]); set(gca,'FontSize',14)
