% Chapter_9_hard_ode_by_laplace.m
%
% An Introduction to Partial Differential Equations with MATLAB
% Third Edition
% Chapter 9: Using MATLAB's Symbolic Math Toolbox with Integral Transforms
% Section 9.2: Solving ODEs Using the Laplace Transform in MATLAB
%
%  2024 by Matthew P. Coleman and Vladislav Bukshtynov
% VladislavBukshtynov@yahoo.com
%

close all; clear; clc;

% Example 2: x'' + x + x^3 = 0, x(0) = 0, x'(0) = 1
t0 = 0; x0 = 0; x1 = 1;                          % initial conditions

% (a) Solution by Symbolic Math Toolbox
syms x(t);                                       % symbolic function
Dx = diff(x);                                    % derivative x'
ode = diff(Dx) + x + x.^3 == 0;                  % ODE
cond = [x(t0) == x0 Dx(t0) == x1];               % ICs
sol1(t) = dsolve(ode,cond)                       % solving IVP

% (b) Solution by applying the Laplace transform
syms X s;                                        % symbolic variables
odeLT = laplace(ode,t,s);                        % Laplace transform
eqnX = subs(odeLT,laplace(x,t,s),X);             % substituting transform
eqnX = subs(eqnX,x(0),x0);                       % substituting x(t0) with x0
eqnX = subs(eqnX,subs(diff(x(t), t), t, 0), x1); % substituting x'(t0) with x1
solX = solve(eqnX,X);                            % solving for unknown X
sol2(t) = ilaplace(solX,s,t)                     % inverse Laplace transform
