% Chapter_9_ode_by_laplace.m
%
% An Introduction to Partial Differential Equations with MATLAB
% Third Edition
% Chapter 9: Using MATLAB's Symbolic Math Toolbox with Integral Transforms
% Section 9.2: Solving ODEs Using the Laplace Transform in MATLAB
%
%  2024 by Matthew P. Coleman and Vladislav Bukshtynov
% VladislavBukshtynov@yahoo.com
%

close all; clear; clc;

% Example 1: y'' + y = sqrt(2)*sin(sqrt(2)t), y(0) = 10, y'(0) = 0
t0 = 0; y0 = 10; y1 = 0;                    % initial conditions

% (a) Solution by Symbolic Math Toolbox
syms y(t);                                  % symbolic function
Dy = diff(y);                               % derivative y'
ode = diff(Dy)+y == sqrt(2)*sin(sqrt(2)*t); % ODE
cond = [y(t0) == y0 Dy(t0) == y1];          % ICs
sol(t) = dsolve(ode,cond);                  % solving IVP
sol1 = simplify(sol)                        % solution y(t)

% (b) Solution by applying the Laplace transform
syms Y s;                                   % symbolic variables
odeLT = laplace(ode,t,s)                    % Laplace transform 
eqnY = subs(odeLT,laplace(y,t,s),Y)         % substituting transform
eqnY = subs(eqnY,y(0),y0)                   % substituting y(t0) with y0
eqnY = subs(eqnY,subs(diff(y(t),t),t,0),y1) % substituting y'(t0) with y1
solY = solve(eqnY,Y)                        % solving for unknown Y
sol2(t) = ilaplace(solY,s,t)                % inverse Laplace transform
