% Chapter_9_symbolic_math_for_transforms.m
%
% An Introduction to Partial Differential Equations with MATLAB
% Third Edition
% Chapter 9: Using MATLAB's Symbolic Math Toolbox with Integral Transforms
% Section 9.1: Integral Transforms via Symbolic Programming
%
%  2024 by Matthew P. Coleman and Vladislav Bukshtynov
% VladislavBukshtynov@yahoo.com
%

close all; clear; clc;

% Plotting Figure 9.1 in Example 1 for Section 9.1
syms f(t) F(s);       % creating symbolic functions
f(t) = 2 - 3*heaviside(t-2) + heaviside(t-3)
F(s) = laplace(f)     % applying Laplace transform
F = simplify(F)       % simplifying solution
f(t) = ilaplace(F)    % applying inverse Laplace transform
f = simplify(f)       % simplifying solution
tt = 0:0.01:5;        % t-interval for plotting
ss = 0.01:0.01:10;    % s-interval for plotting
ft = eval(f(tt));     % evaluating function f(t) over grid tt
Fs = eval(F(ss));     % evaluating function F(s) over grid ss
figure(1); hold on;   % plotting f(t)
plot(tt,ft,'.b','MarkerSize',20);
plot([2 2],[-1 2],'--k'); plot([3 3],[-1 0],'--k');
xlabel('t'); ylabel('f(t)'); set(gca,'FontSize',14); box off;
figure(2); hold on;   % plotting F(s)
plot(ss,Fs,'-r','LineWidth',2.5); xlabel('s'); ylabel('F(s)');
set(gca,'FontSize',14); box off;

% Plotting Figure 9.2 in Example 2 for Section 9.1
syms f(x) F(w);       % creating symbolic functions
f(x) = rectangularPulse(-1, 1, x)
F(w) = fourier(f)     % applying Fourier transform
F = simplify(F)       % simplifying solution
f(x) = ifourier(F)    % applying inverse Fourier transform
f = simplify(f)       % simplifying solution
xx = -5:0.01:5;       % x-interval for plotting
ww = -50:0.03:50;     % (alpha) w-interval for plotting
fx = eval(f(xx));     % evaluating function f(x) over grid xx
Fw = eval(F(ww));     % evaluating function F(w) over grid ww
figure(3); hold on;   % plotting f(x)
plot(xx,fx,'.b','MarkerSize',20);
plot([-1 -1],[0 1],'--k'); plot([1 1],[0 1],'--k');
xlabel('x'); ylabel('f(x)'); set(gca,'FontSize',14); box off;
figure(4); hold on;   % plotting F(w)
plot(ww,Fw,'-r','LineWidth',2.5); xlabel('\alpha'); ylabel('F(\alpha)');
set(gca,'FontSize',14); box off;
